Enum NetError
#[non_exhaustive]pub enum NetError {
Busy,
Dns(DnsError),
Message(&'static str),
Msg(String),
ParseInt(ParseIntError),
NoConnections,
Proto(ProtoError),
Io(Arc<Error>),
Timeout,
QueryCaseMismatch,
}Expand description
The error type for network protocol errors (UDP, TCP, QUIC, H2, H3)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Busy
The underlying resource is too busy
This is a signal that an internal resource is too busy. The intended action should be tried again, ideally after waiting for a little while for the situation to improve. Alternatively, the action could be tried on another resource (for example, in a name server pool).
Dns(DnsError)
Semantic DNS errors
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
ParseInt(ParseIntError)
Unable to parse header value as number
NoConnections
No connections available
Proto(ProtoError)
Protocol error from higher layers
Io(Arc<Error>)
An error got returned from IO
Timeout
A request timed out
QueryCaseMismatch
Case randomization is enabled, and a server did not echo a query name back with the same case.
Implementations
impl NetError
impl NetError
pub fn is_nx_domain(&self) -> bool
pub fn is_nx_domain(&self) -> bool
Returns true if the domain does not exist
pub fn is_no_records_found(&self) -> bool
pub fn is_no_records_found(&self) -> bool
Returns true if the error represents NoRecordsFound